HtmlBoxUIConfig class
Config for HTML media boxes.
iOS only.
Constructors
- HtmlBoxUIConfig({MilibrisColor? backgroundColor})
-
Creates an HTML box UI config.
const
Properties
- backgroundColor → MilibrisColor?
-
The background color. iOS only.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serializes this config to a map for cross-platform transport.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited